#include <QtGui>
#include <QtSql>
#include "mainwindow.h"
#include "dbconfigdialog.h"

MainWindow::MainWindow(QWidget *parent)
    : QMainWindow(parent)
{
    QLabel *dbLabel = new QLabel("Database");
    QComboBox *dbCombo = new QComboBox;
    dbCombo->addItem("default");
    dbCombo->setEnabled(false);
    QPushButton *dbPrefButton = new QPushButton("Config");
    QPushButton *dbConnectButton = new QPushButton("Connect");
    QHBoxLayout *dbLayout = new QHBoxLayout;
    dbLayout->addWidget(dbLabel);
    dbLayout->addWidget(dbCombo);
    dbLayout->addWidget(dbPrefButton);
    dbLayout->addWidget(dbConnectButton);

    queryEdit = new QTextEdit;
    QPushButton *queryExecButton = new QPushButton("Exec");
    QHBoxLayout *queryLayout = new QHBoxLayout;
    queryLayout->addWidget(queryEdit);
    queryLayout->addWidget(queryExecButton);

    resultTable = new QTableView;
    resultModel = new QSqlQueryModel;

    QWidget *mainWidget = new QWidget;
    QVBoxLayout *mainLayout = new QVBoxLayout;
    mainLayout->addLayout(dbLayout);
    mainLayout->addLayout(queryLayout);
    mainLayout->addWidget(resultTable);

    mainWidget->setLayout(mainLayout);
    setCentralWidget(mainWidget);

    connect(queryExecButton,SIGNAL(clicked()),this,SLOT(queryExec()));
    connect(dbPrefButton, SIGNAL(clicked()),this,SLOT(settingsDB()));
    connect(dbConnectButton, SIGNAL(clicked()),this,SLOT(connectDB()));
    statusBar()->showMessage(tr("Ready"));
}

MainWindow::~MainWindow()
{

}

void MainWindow::queryExec()
{
    resultModel->setQuery(queryEdit->toPlainText());
    resultTable->setModel(resultModel);
    resultTable->show();
    statusBar()->showMessage(resultModel->lastError().text());
}

void MainWindow::settingsDB()
{
    DbConfigDialog *dbc = new DbConfigDialog();
    dbc->exec();
}

void MainWindow::connectDB()
{
    QSettings settings;

    QSqlDatabase db = QSqlDatabase::addDatabase(settings.value("DB/driver").toString());
    db.setDatabaseName(settings.value("DB/database").toString());
    if (!db.open())
        QMessageBox::critical(this, tr("Connection error"), tr("Can't open database\n%1").arg(db.lastError().text()), QMessageBox::Ok);
    else
        QMessageBox::information(this,tr("Connection complete"), tr("Connection complete!"),QMessageBox::Ok);
}
